package ch.zhaw.projekt2.turnierverwaltung;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.logging.LogManager;
import java.util.logging.Logger;

/**
 * Class in charge of setting up the Logging functionality properly
 * For further Log settings look into the properties.log file
 */
public class LogConfiguration {
    private static final Logger logger = Logger.getLogger(LogConfiguration.class.getCanonicalName());
    private final File mainDir;

    /**
     * Constructor of LogConfiguration, does the whole setup including reading the properties and setting up a
     * directory for the log files also starts the root logger.
     *
     * @param saveLocation   where the log files should be placed in
     * @param propertiesPath location of the properties.log file
     * @throws IOException if error occurs while reading the log file
     */
    public LogConfiguration(String saveLocation, String propertiesPath) throws IOException {
        logger.fine("Starts setting up a main directory in which a folder with the log files will be placed, if not already exists");
        this.mainDir = new File(saveLocation);
        if (!mainDir.exists()) {
            logger.fine("Creating main directory for log folder in given path" + saveLocation);
            mainDir.mkdir();
        } else {
            logger.finer("main directory for log folder already exists");
        }

        File saves = new File(mainDir, "log_files");
        if (!saves.exists()) {
            saves.mkdir();
            logger.fine("Creating log save directory");
        } else {
            logger.finer("Log save directory already exists");
        }

        logger.fine("Getting and reading log config file from: " + propertiesPath);
        InputStream logConfig = this.getClass().getClassLoader().getResourceAsStream(propertiesPath);
        LogManager.getLogManager().readConfiguration(logConfig);

        Logger.getLogger(LogConfiguration.class.getPackageName());
        logger.fine("Finished setting up Logging functionality");
    }
}
